/*
  Copyright (C) 2013 Harry

 This file is part of spacewar.

 spacewar is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 spacewar is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with spacewar.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _SHIPS_H_
#define _SHIPS_H_

#include "weaver/weaver.h"
#include "game.h"

#define BLOW_UP 10.0
#define DEAD       0
#define ALIVE      1
#define HYPERSPACE 2

#define FUEL       1650.0 // How much fuel each ship have
#define PROPULSORS 2  // Maximum number of propulsors in a ship
#define NUMBER_OF_SHIPS 2
#define SHIP_TURN (M_PI / 2) // Angular speed per second
#define SHIP_ACCEL  50.0 //Ship acceleration

#define HYPERSPACE_TIME 1000000lu
#define HYPERSPACE_FUEL 165.0

struct{
  polygon **body; // Ship's polygons
  unsigned color;
  float x, y;     // Position of the gravity center
  float dx, dy;   // slope
  int status;     // ALIVE, DEAD or HYPERSPACE
  struct timeval time; // Last time the status changed
  float fuel;
  polygon *front;
  polygon *propulsor[PROPULSORS];
} ship[NUMBER_OF_SHIPS];

void blow_up_vertex(int, float, float, float, float, float, float, unsigned);
void blow_up(int);
void initialize_ships(int);
void film_ships(void);
void erase_ships(void);
void destroy_ships(void);
void update_ships(void);
void rotate_ship(int, int);
void propulse_ship(int);
void ship_fire(int);
void goto_hyperspace(int);
void return_hyperspace(int);

#endif
